@@ -57,6 +57,11 @@ class DynamoDBCachingTable(BaseCachingTable, DynamoDBTableConnectors):
             return self.dynamodb_client.delete_record(indexes_keys_selectors=indexes_keys)
         return self._delete_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors)
 
+    def remove_record(self, indexes_keys_selectors: dict) -> Optional[dict]:
+        def middleware(indexes_keys: dict) -> Optional[dict]:
+            return self.dynamodb_client.remove_record(indexes_keys_selectors=indexes_keys)
+        return self._remove_record(middleware=middleware, indexes_keys_selectors=indexes_keys_selectors)
+
     def query_field(
             self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None, index_name: Optional[str] = None,
             records_query_limit: Optional[int] = None, filter_expression: Optional[Any] = None, **additional_kwargs
